summary refs log tree commit diff
path: root/arch/s390/mm/mmap.c
diff options
context:
space:
mode:
authorSven Schnelle <svens@linux.ibm.com>2022-04-06 08:01:24 +0200
committerHeiko Carstens <hca@linux.ibm.com>2022-04-25 13:54:14 +0200
commitf2f47d0ef72c30622e62471903ea19446ea79ee2 (patch)
tree8cd6dbb59bbfbb7269d093351f3609ec5f63cb82 /arch/s390/mm/mmap.c
parent2004b57cde6b21170d058244b53043105d89f83f (diff)
downloadlinux-f2f47d0ef72c30622e62471903ea19446ea79ee2.tar.gz
s390/mmap: increase stack/mmap gap to 128MB
This basically reverts commit 9e78a13bfb16 ("[S390] reduce miminum
gap between stack and mmap_base"). 32MB is not enough space
between stack and mmap for some programs. Given that compat
task aren't common these days, lets revert back to 128MB.

Signed-off-by: Sven Schnelle <svens@linux.ibm.com>
Reviewed-by: Heiko Carstens <hca@linux.ibm.com>
Signed-off-by: Heiko Carstens <hca@linux.ibm.com>
Diffstat (limited to 'arch/s390/mm/mmap.c')
-rw-r--r--arch/s390/mm/mmap.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/arch/s390/mm/mmap.c b/arch/s390/mm/mmap.c
index e54f928503c5..d545f5c39f7e 100644
--- a/arch/s390/mm/mmap.c
+++ b/arch/s390/mm/mmap.c
@@ -58,9 +58,9 @@ static inline unsigned long mmap_base(unsigned long rnd,
 
 	/*
 	 * Top of mmap area (just below the process stack).
 	 * Leave at least a ~32 MB hole.
 	 */
-	gap_min = 32 * 1024 * 1024UL;
+	gap_min = SZ_128M;
 	gap_max = (STACK_TOP / 6) * 5;
 
 	if (gap < gap_min)
@@ -58,9 +58,9 @@ static inline unsigned long mmap_base(unsigned long rnd,
 	/*
 	 * Top of mmap area (just below the process stack).
-	 * Leave at least a ~32 MB hole.
+	 * Leave at least a ~128 MB hole.
 	 */